# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationRunway(Model):
    """Various pieces of information associated with a runway.

    :param id: The unique identifier for the runway.
    :type id: int
    :param airport_id: The unique identifier of the airport for this runway.
    :type airport_id: int
    :param string: A text value associated with the runway.
    :type string: str
    :param length: The length of the runway.
    :type length: float
    :param width: The width of the runway.
    :type width: float
    :param opposite_id: The dafif id of the reciprocal runway (i.e. landing in
     the opposite direction on this runway).
    :type opposite_id: int
    :param is_parallel: Whether the runway is parallel.
    :type is_parallel: bool
    :param heading_true: The true heading of the runway
    :type heading_true: float
    :param heading_magnetic: The magnetic heading of the runway.
    :type heading_magnetic: float
    :param takeoff_distance: The takeoff distance of the runway.
    :type takeoff_distance: float
    :param landing_distance: The landing distance of the runway.
    :type landing_distance: float
    :param latitude_start: The runway's starting latitude.
    :type latitude_start: float
    :param latitude_end: The runway's ending latitude.
    :type latitude_end: float
    :param longitude_start: The runway's starting longitude.
    :type longitude_start: float
    :param longitude_end: The runway's ending longitude.
    :type longitude_end: float
    :param altitude_start: The runway's starting altitude.
    :type altitude_start: float
    :param altitude_end: The runway's ending altitude.
    :type altitude_end: float
    :param slope: The slope of the runway.
    :type slope: float
    :param threshold_displaced: The threshold displaced value associated with
     the runway.
    :type threshold_displaced: float
    :param threshold_latitude: The threshold latitude value associated with
     the runway.
    :type threshold_latitude: float
    :param threshold_longitude: The threshold longitude value associated with
     the runway.
    :type threshold_longitude: float
    :param threshold_elevation: The threshold elevation value associated with
     the runway.
    :type threshold_elevation: float
    :param threshold_cross_height: The threshold crossheight value associated
     with the runway.
    :type threshold_cross_height: float
    :param threshold_to_glideslope_distance: The threshold to glideslope
     distance associated with the runway.
    :type threshold_to_glideslope_distance: float
    :param lighting: Bitflags indicating the available lighting for the
     runway.
    :type lighting: str
    :param glideslope_angle: The glideslope angle value associated with the
     runway.
    :type glideslope_angle: float
    :param glideslope_latitude: The glideslope latitude value associated with
     the runway.
    :type glideslope_latitude: float
    :param glideslope_longitude: The glideslope longitude value associated
     with the runway.
    :type glideslope_longitude: float
    :param glideslope_altitude: The glideslope altitude value associated with
     the runway.
    :type glideslope_altitude: float
    :param localizer_width: The localizer width value associated with the
     runway.
    :type localizer_width: float
    :param localizer_navaid: The navaid id of the localizer navaid.
    :type localizer_navaid: int
    :param localizer_frequency: The localizer frequency value associated with
     the runway.
    :type localizer_frequency: float
    :param backcourse_localizer_frequency: The backcourse localizer frequency
     value associated with the runway.
    :type backcourse_localizer_frequency: float
    :param ils_bearing_course: The magnetic heading to fly the ILS.
    :type ils_bearing_course: float
    :param dme_navaid: The navid id of the localizer dme.
    :type dme_navaid: int
    :param dme_bias: The DME bias for the runway (the distance in NM from the
     DME to the landing threshold).
    :type dme_bias: float
    :param inner_marker_latitude: The inner marker latitude value associated
     with the runway.
    :type inner_marker_latitude: float
    :param inner_marker_longitude: The inner marker longitude value associated
     with the runway.
    :type inner_marker_longitude: float
    :param inner_marker_altitude: The inner marker altitude value associated
     with the runway.
    :type inner_marker_altitude: float
    :param middle_marker_navaid: The navaid id of the middle marker, if any.
    :type middle_marker_navaid: int
    :param middle_marker_latitude: The middle marker latitude value associated
     with the runway.
    :type middle_marker_latitude: float
    :param middle_marker_longitude: The middle marker longitude value
     associated with the runway.
    :type middle_marker_longitude: float
    :param middle_marker_altitude: The middle marker altitude value associated
     with the runway.
    :type middle_marker_altitude: float
    :param outer_marker_navaid: The navaid id of the outer marker, if any.
    :type outer_marker_navaid: float
    :param outer_marker_latitude: The outer marker latitude value associated
     with the runway.
    :type outer_marker_latitude: float
    :param outer_marker_longitude: The outer marker longitude value associated
     with the runway.
    :type outer_marker_longitude: float
    :param outer_marker_altitude: The outer marker altitude value associated
     with the runway.
    :type outer_marker_altitude: float
    :param locator_navaid: The navaid id of the compass locator, if any.
    :type locator_navaid: int
    :param locator_latitude: The locator latitude value associated with the
     runway.
    :type locator_latitude: float
    :param locator_longitude: The locator longitude value associated with the
     runway.
    :type locator_longitude: float
    :param locator_altitude: The locator altitude value associated with the
     runway.
    :type locator_altitude: float
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'airport_id': {'key': 'airportId', 'type': 'int'},
        'string': {'key': 'string', 'type': 'str'},
        'length': {'key': 'length', 'type': 'float'},
        'width': {'key': 'width', 'type': 'float'},
        'opposite_id': {'key': 'oppositeId', 'type': 'int'},
        'is_parallel': {'key': 'isParallel', 'type': 'bool'},
        'heading_true': {'key': 'headingTrue', 'type': 'float'},
        'heading_magnetic': {'key': 'headingMagnetic', 'type': 'float'},
        'takeoff_distance': {'key': 'takeoffDistance', 'type': 'float'},
        'landing_distance': {'key': 'landingDistance', 'type': 'float'},
        'latitude_start': {'key': 'latitudeStart', 'type': 'float'},
        'latitude_end': {'key': 'latitudeEnd', 'type': 'float'},
        'longitude_start': {'key': 'longitudeStart', 'type': 'float'},
        'longitude_end': {'key': 'longitudeEnd', 'type': 'float'},
        'altitude_start': {'key': 'altitudeStart', 'type': 'float'},
        'altitude_end': {'key': 'altitudeEnd', 'type': 'float'},
        'slope': {'key': 'slope', 'type': 'float'},
        'threshold_displaced': {'key': 'thresholdDisplaced', 'type': 'float'},
        'threshold_latitude': {'key': 'thresholdLatitude', 'type': 'float'},
        'threshold_longitude': {'key': 'thresholdLongitude', 'type': 'float'},
        'threshold_elevation': {'key': 'thresholdElevation', 'type': 'float'},
        'threshold_cross_height': {'key': 'thresholdCrossHeight', 'type': 'float'},
        'threshold_to_glideslope_distance': {'key': 'thresholdToGlideslopeDistance', 'type': 'float'},
        'lighting': {'key': 'lighting', 'type': 'str'},
        'glideslope_angle': {'key': 'glideslopeAngle', 'type': 'float'},
        'glideslope_latitude': {'key': 'glideslopeLatitude', 'type': 'float'},
        'glideslope_longitude': {'key': 'glideslopeLongitude', 'type': 'float'},
        'glideslope_altitude': {'key': 'glideslopeAltitude', 'type': 'float'},
        'localizer_width': {'key': 'localizerWidth', 'type': 'float'},
        'localizer_navaid': {'key': 'localizerNavaid', 'type': 'int'},
        'localizer_frequency': {'key': 'localizerFrequency', 'type': 'float'},
        'backcourse_localizer_frequency': {'key': 'backcourseLocalizerFrequency', 'type': 'float'},
        'ils_bearing_course': {'key': 'ilsBearingCourse', 'type': 'float'},
        'dme_navaid': {'key': 'dmeNavaid', 'type': 'int'},
        'dme_bias': {'key': 'dmeBias', 'type': 'float'},
        'inner_marker_latitude': {'key': 'innerMarkerLatitude', 'type': 'float'},
        'inner_marker_longitude': {'key': 'innerMarkerLongitude', 'type': 'float'},
        'inner_marker_altitude': {'key': 'innerMarkerAltitude', 'type': 'float'},
        'middle_marker_navaid': {'key': 'middleMarkerNavaid', 'type': 'int'},
        'middle_marker_latitude': {'key': 'middleMarkerLatitude', 'type': 'float'},
        'middle_marker_longitude': {'key': 'middleMarkerLongitude', 'type': 'float'},
        'middle_marker_altitude': {'key': 'middleMarkerAltitude', 'type': 'float'},
        'outer_marker_navaid': {'key': 'outerMarkerNavaid', 'type': 'float'},
        'outer_marker_latitude': {'key': 'outerMarkerLatitude', 'type': 'float'},
        'outer_marker_longitude': {'key': 'outerMarkerLongitude', 'type': 'float'},
        'outer_marker_altitude': {'key': 'outerMarkerAltitude', 'type': 'float'},
        'locator_navaid': {'key': 'locatorNavaid', 'type': 'int'},
        'locator_latitude': {'key': 'locatorLatitude', 'type': 'float'},
        'locator_longitude': {'key': 'locatorLongitude', 'type': 'float'},
        'locator_altitude': {'key': 'locatorAltitude', 'type': 'float'},
    }

    def __init__(self, *, id: int=None, airport_id: int=None, string: str=None, length: float=None, width: float=None, opposite_id: int=None, is_parallel: bool=None, heading_true: float=None, heading_magnetic: float=None, takeoff_distance: float=None, landing_distance: float=None, latitude_start: float=None, latitude_end: float=None, longitude_start: float=None, longitude_end: float=None, altitude_start: float=None, altitude_end: float=None, slope: float=None, threshold_displaced: float=None, threshold_latitude: float=None, threshold_longitude: float=None, threshold_elevation: float=None, threshold_cross_height: float=None, threshold_to_glideslope_distance: float=None, lighting: str=None, glideslope_angle: float=None, glideslope_latitude: float=None, glideslope_longitude: float=None, glideslope_altitude: float=None, localizer_width: float=None, localizer_navaid: int=None, localizer_frequency: float=None, backcourse_localizer_frequency: float=None, ils_bearing_course: float=None, dme_navaid: int=None, dme_bias: float=None, inner_marker_latitude: float=None, inner_marker_longitude: float=None, inner_marker_altitude: float=None, middle_marker_navaid: int=None, middle_marker_latitude: float=None, middle_marker_longitude: float=None, middle_marker_altitude: float=None, outer_marker_navaid: float=None, outer_marker_latitude: float=None, outer_marker_longitude: float=None, outer_marker_altitude: float=None, locator_navaid: int=None, locator_latitude: float=None, locator_longitude: float=None, locator_altitude: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationRunway, self).__init__(**kwargs)
        self.id = id
        self.airport_id = airport_id
        self.string = string
        self.length = length
        self.width = width
        self.opposite_id = opposite_id
        self.is_parallel = is_parallel
        self.heading_true = heading_true
        self.heading_magnetic = heading_magnetic
        self.takeoff_distance = takeoff_distance
        self.landing_distance = landing_distance
        self.latitude_start = latitude_start
        self.latitude_end = latitude_end
        self.longitude_start = longitude_start
        self.longitude_end = longitude_end
        self.altitude_start = altitude_start
        self.altitude_end = altitude_end
        self.slope = slope
        self.threshold_displaced = threshold_displaced
        self.threshold_latitude = threshold_latitude
        self.threshold_longitude = threshold_longitude
        self.threshold_elevation = threshold_elevation
        self.threshold_cross_height = threshold_cross_height
        self.threshold_to_glideslope_distance = threshold_to_glideslope_distance
        self.lighting = lighting
        self.glideslope_angle = glideslope_angle
        self.glideslope_latitude = glideslope_latitude
        self.glideslope_longitude = glideslope_longitude
        self.glideslope_altitude = glideslope_altitude
        self.localizer_width = localizer_width
        self.localizer_navaid = localizer_navaid
        self.localizer_frequency = localizer_frequency
        self.backcourse_localizer_frequency = backcourse_localizer_frequency
        self.ils_bearing_course = ils_bearing_course
        self.dme_navaid = dme_navaid
        self.dme_bias = dme_bias
        self.inner_marker_latitude = inner_marker_latitude
        self.inner_marker_longitude = inner_marker_longitude
        self.inner_marker_altitude = inner_marker_altitude
        self.middle_marker_navaid = middle_marker_navaid
        self.middle_marker_latitude = middle_marker_latitude
        self.middle_marker_longitude = middle_marker_longitude
        self.middle_marker_altitude = middle_marker_altitude
        self.outer_marker_navaid = outer_marker_navaid
        self.outer_marker_latitude = outer_marker_latitude
        self.outer_marker_longitude = outer_marker_longitude
        self.outer_marker_altitude = outer_marker_altitude
        self.locator_navaid = locator_navaid
        self.locator_latitude = locator_latitude
        self.locator_longitude = locator_longitude
        self.locator_altitude = locator_altitude



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestSite(Model):
    """AdiEmsWebSharedTableauRestSite.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param content_url:
    :type content_url: str
    :param admin_mode:
    :type admin_mode: str
    :param user_quota:
    :type user_quota: str
    :param storage_quota:
    :type storage_quota: str
    :param state:
    :type state: str
    :param status_reason:
    :type status_reason: str
    :param revision_history_enabled:
    :type revision_history_enabled: bool
    :param subscribe_others_enabled:
    :type subscribe_others_enabled: bool
    :param revision_limit:
    :type revision_limit: int
    :param guest_access_enabled:
    :type guest_access_enabled: bool
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'content_url': {'key': 'contentUrl', 'type': 'str'},
        'admin_mode': {'key': 'adminMode', 'type': 'str'},
        'user_quota': {'key': 'userQuota', 'type': 'str'},
        'storage_quota': {'key': 'storageQuota', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'status_reason': {'key': 'statusReason', 'type': 'str'},
        'revision_history_enabled': {'key': 'revisionHistoryEnabled', 'type': 'bool'},
        'subscribe_others_enabled': {'key': 'subscribeOthersEnabled', 'type': 'bool'},
        'revision_limit': {'key': 'revisionLimit', 'type': 'int'},
        'guest_access_enabled': {'key': 'guestAccessEnabled', 'type': 'bool'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebSharedTableauRestSite, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.content_url = kwargs.get('content_url', None)
        self.admin_mode = kwargs.get('admin_mode', None)
        self.user_quota = kwargs.get('user_quota', None)
        self.storage_quota = kwargs.get('storage_quota', None)
        self.state = kwargs.get('state', None)
        self.status_reason = kwargs.get('status_reason', None)
        self.revision_history_enabled = kwargs.get('revision_history_enabled', None)
        self.subscribe_others_enabled = kwargs.get('subscribe_others_enabled', None)
        self.revision_limit = kwargs.get('revision_limit', None)
        self.guest_access_enabled = kwargs.get('guest_access_enabled', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions(Model):
    """Specifies options to use when calling the METAR parse API.

    All required parameters must be populated in order to send to Azure.

    :param metar: Required. The raw METAR string to parse
    :type metar: str
    :param issue_date: Optional date information (in ISO 8601 format) the
     METAR was issued, since the METAR format only includes
     day, hour and minute time information.
    :type issue_date: datetime
    """

    _validation = {
        'metar': {'required': True},
    }

    _attribute_map = {
        'metar': {'key': 'metar', 'type': 'str'},
        'issue_date': {'key': 'issueDate', 'type': 'iso-8601'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions, self).__init__(**kwargs)
        self.metar = kwargs.get('metar', None)
        self.issue_date = kwargs.get('issue_date', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class DatabaseOperations(object):
    """DatabaseOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_database_group(
            self, ems_system_id, group_id=None, custom_headers=None, raw=False, **operation_config):
        """Returns a database group with a matching ID containing only its
        immediate children in a hierarchical tree
        used to organize databases.

        Each EMS system has its own configured set of databases that are
        available for querying, such as flights,
        downloads and events. Databases are organized using database groups in
        a tree structure since EMS
        systems might expose a large number of databases. This API allows you
        to see one level of the tree
        structure.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param group_id: The unique identifier of the EMS database group whose
         contents to return.
         If not specified, the contents of the root group are returned.
        :type group_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_database_group.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if group_id is not None:
            query_parameters['groupId'] = self._serialize.query("group_id", group_id, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoSchemaDatabaseGroup', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_database_group.metadata = {'url': '/v2/ems-systems/{emsSystemId}/database-groups'}

    def get_field_group(
            self, ems_system_id, database_id, group_id=None, custom_headers=None, raw=False, **operation_config):
        """Returns a field group with a matching ID containing only its immediate
        children in a hierarchical tree used
        to organize fields.

        Fields are organized using field groups in a tree structure since EMS
        systems and databases might expose
        a large number of fields. This API allows you to see one level of the
        tree structure. This API returns only
        a minimal amount of information about the fields returned. To get
        additional details for an individual,
        field, see the "field" resource below.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the EMS database
         containing a field group to return.
        :type database_id: str
        :param group_id: The unique identifier of a field group whose contents
         to return. If not
         specified, the contents of the root group are returned.
        :type group_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_field_group.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if group_id is not None:
            query_parameters['groupId'] = self._serialize.query("group_id", group_id, 'str')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoSchemaFieldGroup', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_field_group.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/field-groups'}

    def get_field(
            self, ems_system_id, database_id, field_id, custom_headers=None, raw=False, **operation_config):
        """Returns information about a database field matching the specified ID.

        Fields are elements in an EMS system that can be queried for results.
        For more details on how to query for
        results, see the "query" resource below.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the EMS database
         containing a field to return.
        :type database_id: str
        :param field_id: The unique identifier of the field whose information
         to return.
        :type field_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_field.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str'),
            'fieldId': self._serialize.url("field_id", field_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoSchemaField', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_field.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/fields/{fieldId}'}

    def get_fields(
            self, ems_system_id, database_id, search=None, field_group_id=None, include_profiles=None, max_results=None, custom_headers=None, raw=False, **operation_config):
        """Returns all the fields matching the specified search options.

        This API will return fields matching your search options. If no fields
        are found, an empty list is returned.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the database containing
         fields to return.
        :type database_id: str
        :param search: An optional field name search string used to match
         fields to return.
        :type search: str
        :param field_group_id: The optional parent field group ID whose
         contents to search.
        :type field_group_id: str
        :param include_profiles: An optional setting to indicate whether to
         search fields in profiles. By
         default, this is false since including profile fields will
         significantly increase search time.
        :type include_profiles: bool
        :param max_results: The maximum number of fields to return. This
         defaults to 200 fields.
         If this is set to 0 all the results will be returned.
        :type max_results: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_fields.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if search is not None:
            query_parameters['search'] = self._serialize.query("search", search, 'str')
        if field_group_id is not None:
            query_parameters['fieldGroupId'] = self._serialize.query("field_group_id", field_group_id, 'str')
        if include_profiles is not None:
            query_parameters['includeProfiles'] = self._serialize.query("include_profiles", include_profiles, 'bool')
        if max_results is not None:
            query_parameters['maxResults'] = self._serialize.query("max_results", max_results, 'int')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoSchemaField]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_fields.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/fields'}

    def get_query_results(
            self, ems_system_id, database_id, query, custom_headers=None, raw=False, **operation_config):
        """Queries a database for information, composing the query with
        information provided in the specified
        query structure.

        <p>The advantage of this query route over async-query is its
        simplicity. This route executes a query and
        returns the results in a single API call. Due to memory and network
        resource limitations, this route cannot
        be used to fetch large result sets. The route limits the maximum number
        of result rows that can be returned
        for a single query. If you do not specify a "top" limit to the results
        and the number of rows queried
        exceeds the maximum allowed, the partial result boolean flag included
        in the response will be set to true.
        If you need to access larger result sets, use the async-query route
        instead.</p>
        <p>Queries can contain reference to one or more fields and can include
        more complex querying operations
        including: filtering, grouping, and sorting (by value). These
        operations are specified by the query model
        you provide the API.</p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the EMS database to
         query.
        :type database_id: str
        :param query: The information used to construct a query for which
         results are returned.
        :type query: ~emsapi.models.AdiEmsWebApiV2DtoSchemaQuery
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_query_results.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(query, 'AdiEmsWebApiV2DtoSchemaQuery')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoSchemaQueryResult', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_query_results.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/query'}

    def start_async_query(
            self, ems_system_id, database_id, query, custom_headers=None, raw=False, **operation_config):
        """Creates a query on a database using the provided query structure and
        returns an ID that can be used to
        fetch result data through other async-query routes.

        <p>The advantage of the async-query routes over the basic query route
        is their ability to return very large
        result sets, split across many API calls. For queries with small result
        sets, you may prefer to use the
        basic query route, as it provides the simplicity of executing a query
        and returning the results in one call.
        </p>
        <p>Use the <b>GET
        v2/ems/{emsSystemId}/databases/{databaseId}/async-query/{queryId}/read/{start}/{end}</b>
        route to read rows from the async-query result set.</p>
        <p>Use the <b>DELETE
        v2/ems/{emsSystemId}/databases/{databaseId}/async-query/{queryId}</b>
        route to stop
        an async query.</p>
        <p>Queries can contain reference to one or more fields and can include
        more complex querying operations
        including: filtering, grouping, and sorting (by value). These
        operations are specified by the query model
        you provide the API.</p>.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the EMS database to
         query.
        :type database_id: str
        :param query: The information used to construct a query.
        :type query: ~emsapi.models.AdiEmsWebApiV2DtoSchemaQuery
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.start_async_query.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        header_parameters['Content-Type'] = 'application/json; charset=utf-8'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct body
        body_content = self._serialize.body(query, 'AdiEmsWebApiV2DtoSchemaQuery')

        # Construct and send request
        request = self._client.post(url, query_parameters, header_parameters, body_content)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoSchemaAsyncQueryInfo', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    start_async_query.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/async-query'}

    def read_async_query(
            self, ems_system_id, database_id, query_id, start, end, custom_headers=None, raw=False, **operation_config):
        """Returns rows between (inclusive) the start and end indexes from the
        async query with the given ID.

        You can choose the number of rows returned by specifying an inclusive
        range of rows with the start and end
        indexes. However, this route also limits the maximum number of result
        rows that can be reasonably returned
        in a single call. If more values need to be read, simply make multiple
        calls to this route and use
        the "hasMoreRows" flag to determine if the returned rows are the last
        rows in the query's result set.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the EMS database to
         query.
        :type database_id: str
        :param query_id: The unique identifier of the query created by the
         API.
        :type query_id: str
        :param start: The zero-based index of the first row to return.
        :type start: int
        :param end: The zero-based index of the last row to return.
        :type end: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.read_async_query.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str'),
            'queryId': self._serialize.url("query_id", query_id, 'str'),
            'start': self._serialize.url("start", start, 'int'),
            'end': self._serialize.url("end", end, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 400, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoSchemaAsyncQueryData', response)
        if response.status_code == 400:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    read_async_query.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/async-query/{queryId}/read/{start}/{end}'}

    def stop_async_query(
            self, ems_system_id, database_id, query_id, custom_headers=None, raw=False, **operation_config):
        """Stops the async query with the given ID.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param database_id: The unique identifier of the EMS database to
         query.
        :type database_id: str
        :param query_id: The unique identifier of the query created by the
         API.
        :type query_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.stop_async_query.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'databaseId': self._serialize.url("database_id", database_id, 'str'),
            'queryId': self._serialize.url("query_id", query_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.delete(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [204, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 204:
            deserialized = self._deserialize('object', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    stop_async_query.metadata = {'url': '/v2/ems-systems/{emsSystemId}/databases/{databaseId}/async-query/{queryId}'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoProfileProfile(Model):
    """Represents an APM (Automated Parameter Measurement) profile in an EMS
    system.

    All required parameters must be populated in order to send to Azure.

    :param local_id: Required. The local integer identifier for the profile
    :type local_id: int
    :param id: Required. The globally unique identifier of the profile
    :type id: str
    :param name: Required. The display name of the profile
    :type name: str
    :param library: Required. Indicates whether the profile is a "library"
     profile
    :type library: bool
    :param current_version: Required. The current integer version of the
     profile
    :type current_version: int
    """

    _validation = {
        'local_id': {'required': True},
        'id': {'required': True},
        'name': {'required': True},
        'library': {'required': True},
        'current_version': {'required': True},
    }

    _attribute_map = {
        'local_id': {'key': 'localId', 'type': 'int'},
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'library': {'key': 'library', 'type': 'bool'},
        'current_version': {'key': 'currentVersion', 'type': 'int'},
    }

    def __init__(self, *, local_id: int, id: str, name: str, library: bool, current_version: int, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoProfileProfile, self).__init__(**kwargs)
        self.local_id = local_id
        self.id = id
        self.name = name
        self.library = library
        self.current_version = current_version



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoTrajectoryValue(Model):
    """Encapsulates a data point defining the positional information
    [lat/long/alt]
    for a sample and the location it occurred at, in seconds from start of
    file.

    :param offset: The offset of the value, in seconds from start of file.
    :type offset: float
    :param latitude: The latitude related to the offset at
     {Adi.Ems.Web.Api.V2.Dto.TrajectoryValue.Offset}.
    :type latitude: float
    :param longitude: The longitude related to the offset at
     {Adi.Ems.Web.Api.V2.Dto.TrajectoryValue.Offset}.
    :type longitude: float
    :param altitude: The altitude related to the offset at
     {Adi.Ems.Web.Api.V2.Dto.TrajectoryValue.Offset}.
    :type altitude: float
    """

    _attribute_map = {
        'offset': {'key': 'offset', 'type': 'float'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'altitude': {'key': 'altitude', 'type': 'float'},
    }

    def __init__(self, *, offset: float=None, latitude: float=None, longitude: float=None, altitude: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoTrajectoryValue, self).__init__(**kwargs)
        self.offset = offset
        self.latitude = latitude
        self.longitude = longitude
        self.altitude = altitude



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAssetAirport(Model):
    """Encapsulates the definition of an airport.

    :param id: The identifier of the airport within the system.
    :type id: int
    :param code_iata: The IATA code associated with this airport.
    :type code_iata: str
    :param code_icao: The ICAO code associated with this airport.
    :type code_icao: str
    :param code_faa: The FAA / Regional code associated with this airport.
    :type code_faa: str
    :param code_preferred: The preferred code to use for display. This is
     typically either the ICAO or FAA code, but can be overridden by the user.
    :type code_preferred: str
    :param name: The name of the airport.
    :type name: str
    :param city: The city of the airport.
    :type city: str
    :param country: The country of the airport.
    :type country: str
    :param latitude: The latitude of the airport.
    :type latitude: float
    :param longitude: The longitude of the airport.
    :type longitude: float
    :param elevation: The elevation of the airport, in feet.
    :type elevation: float
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'code_iata': {'key': 'codeIata', 'type': 'str'},
        'code_icao': {'key': 'codeIcao', 'type': 'str'},
        'code_faa': {'key': 'codeFaa', 'type': 'str'},
        'code_preferred': {'key': 'codePreferred', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'elevation': {'key': 'elevation', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoAssetAirport, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.code_iata = kwargs.get('code_iata', None)
        self.code_icao = kwargs.get('code_icao', None)
        self.code_faa = kwargs.get('code_faa', None)
        self.code_preferred = kwargs.get('code_preferred', None)
        self.name = kwargs.get('name', None)
        self.city = kwargs.get('city', None)
        self.country = kwargs.get('country', None)
        self.latitude = kwargs.get('latitude', None)
        self.longitude = kwargs.get('longitude', None)
        self.elevation = kwargs.get('elevation', None)



from setuptools import setup, find_packages

def readme():
    with open('README.md') as f:
        return f.read()
    
def requirements():
    with open('requirements.txt') as f:
        return f.read().splitlines()

setup(name = 'emsapi',
      version = '0.1.2',
      description = 'A Python EMS RESTful API Client/Wrapper',
      long_description=readme(),
      long_description_content_type="text/markdown",
      classifiers = [
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License'
        ],
      url = 'https://github.com/ge-flight-analytics/emsapi-python',
      author = 'GE Flight Analytics',
      author_email = 'AviationAdiSupport@ge.com',
      license = 'MIT',
      packages = find_packages(exclude=("docs","tools")),
      install_requires = requirements(),
      zip_safe = False)
      



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class HtmlDocumentationOperations(object):
    """HtmlDocumentationOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_html_documentation(
            self, version, custom_headers=None, raw=False, **operation_config):
        """Returns the HTML documentation for the specified version of the API.

        The HTML documentation is returned as a "text/html" media type.

        :param version: The version of the API for which documentation is
         returned, e.g. "v1", "v2".
        :type version: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_html_documentation.metadata['url']
        path_format_arguments = {
            'version': self._serialize.url("version", version, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 404, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('str', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 404:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_html_documentation.metadata = {'url': '/v2/html-documentation/{version}'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticOffsetType(Model):
    """Class for determining which offsets to sample an analytic at.

    All required parameters must be populated in order to send to Azure.

    :param type: Required. Determines the way to retrieve samples for an
     analytic query. Possible values include: 'sampledValues', 'fixedRate'
    :type type: str or ~emsapi.models.enum
    :param sampling_rate: Offsets are calculated using this sampling rate when
     using 'FixedRate' sampling type.
    :type sampling_rate: float
    """

    _validation = {
        'type': {'required': True},
    }

    _attribute_map = {
        'type': {'key': 'type', 'type': 'str'},
        'sampling_rate': {'key': 'samplingRate', 'type': 'float'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2ModelAnalyticOffsetType, self).__init__(**kwargs)
        self.type = kwargs.get('type', None)
        self.sampling_rate = kwargs.get('sampling_rate', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2ModelAnalyticAnalyticResult(Model):
    """Represents the results of a query of an individual analytic, housing the
    values for the offsets contained
    in the related query result.

    All required parameters must be populated in order to send to Azure.

    :param analytic_id: Required. The unique string identifier of the analytic
     queried
    :type analytic_id: str
    :param values: Required. The array of analytic values corresponding to
     offsets specified in the query result
    :type values: list[object]
    :param error: Any error that may have occurred when retrieving or
     attempting to retrieve the values for the analytic.
     This field is only available if there is an error.
    :type error: str
    """

    _validation = {
        'analytic_id': {'required': True},
        'values': {'required': True},
    }

    _attribute_map = {
        'analytic_id': {'key': 'analyticId', 'type': 'str'},
        'values': {'key': 'values', 'type': '[object]'},
        'error': {'key': 'error', 'type': 'str'},
    }

    def __init__(self, *, analytic_id: str, values, error: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2ModelAnalyticAnalyticResult, self).__init__(**kwargs)
        self.analytic_id = analytic_id
        self.values = values
        self.error = error



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebSharedTableauRestUser(Model):
    """AdiEmsWebSharedTableauRestUser.

    :param id:
    :type id: str
    :param name:
    :type name: str
    :param site_role:
    :type site_role: str
    :param last_login:
    :type last_login: datetime
    :param external_auth_user_id:
    :type external_auth_user_id: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'site_role': {'key': 'siteRole', 'type': 'str'},
        'last_login': {'key': 'lastLogin', 'type': 'iso-8601'},
        'external_auth_user_id': {'key': 'externalAuthUserId', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebSharedTableauRestUser, self).__init__(**kwargs)
        self.id = kwargs.get('id', None)
        self.name = kwargs.get('name', None)
        self.site_role = kwargs.get('site_role', None)
        self.last_login = kwargs.get('last_login', None)
        self.external_auth_user_id = kwargs.get('external_auth_user_id', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid(Model):
    """A single navaid associated with a procedure segment.

    :param navaid_id: The ID of the navaid referenced by this segment.
    :type navaid_id: int
    :param bearing: The bearing to the navaid.
    :type bearing: float
    :param distance: The distance to the navaid.
    :type distance: float
    """

    _attribute_map = {
        'navaid_id': {'key': 'navaidId', 'type': 'int'},
        'bearing': {'key': 'bearing', 'type': 'float'},
        'distance': {'key': 'distance', 'type': 'float'},
    }

    def __init__(self, *, navaid_id: int=None, bearing: float=None, distance: float=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid, self).__init__(**kwargs)
        self.navaid_id = navaid_id
        self.bearing = bearing
        self.distance = distance



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaDatabaseGroup(Model):
    """Represents a folder in the database tree of an EMS installation.

    All required parameters must be populated in order to send to Azure.

    :param id: Required. The unique string identifier for the database group
    :type id: str
    :param name: Required. The display name for the database group
    :type name: str
    :param groups: An ordered listing of child database groups contained in
     this group
    :type groups: list[~emsapi.models.AdiEmsWebApiV2DtoSchemaDatabaseGroup]
    :param databases: An ordered listing of child databases contained in this
     group
    :type databases: list[~emsapi.models.AdiEmsWebApiV2DtoSchemaDatabase]
    """

    _validation = {
        'id': {'required': True},
        'name': {'required': True},
    }

    _attribute_map = {
        'id': {'key': 'id', 'type': 'str'},
        'name': {'key': 'name', 'type': 'str'},
        'groups': {'key': 'groups', 'type': '[AdiEmsWebApiV2DtoSchemaDatabaseGroup]'},
        'databases': {'key': 'databases', 'type': '[AdiEmsWebApiV2DtoSchemaDatabase]'},
    }

    def __init__(self, *, id: str, name: str, groups=None, databases=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaDatabaseGroup, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.groups = groups
        self.databases = databases



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoParameterSetParameterSet(Model):
    """Encapsulates the some data defining a ParameterSet.

    :param name: The name of the ParameterSet.
    :type name: str
    :param description: An optional description of the ParameterSet.
    :type description: str
    :param items: An array of the parameters contained in the ParameterSet.
    :type items:
     list[~emsapi.models.AdiEmsWebApiV2DtoParameterSetParameterSetItem]
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'items': {'key': 'items', 'type': '[AdiEmsWebApiV2DtoParameterSetParameterSetItem]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoParameterSetParameterSet, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.items = kwargs.get('items', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaGroupByColumn(Model):
    """Represents a column of data that can be used in a group-by clause of a data
    source query.

    All required parameters must be populated in order to send to Azure.

    :param field_id: Required. The unique string identifier of the field to
     use in a group-by clause of a query
    :type field_id: str
    """

    _validation = {
        'field_id': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'str'},
    }

    def __init__(self, *, field_id: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoSchemaGroupByColumn, self).__init__(**kwargs)
        self.field_id = field_id



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoMetadataItem(Model):
    """Encapsulates a single piece of metadata.

    :param key: The metadata key.
    :type key: str
    :param value: The metadata value.
    :type value: object
    """

    _attribute_map = {
        'key': {'key': 'key', 'type': 'str'},
        'value': {'key': 'value', 'type': 'object'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoMetadataItem, self).__init__(**kwargs)
        self.key = kwargs.get('key', None)
        self.value = kwargs.get('value', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoNavigationNavigationAirport(Model):
    """Information about a single airport.

    :param id: The unique identifier for this airport.
    :type id: int
    :param name: The name of the airport.
    :type name: str
    :param ata_code: The ATA (FAA) code is the US-specific 3-letter identifier
     (e.g. ORD)
    :type ata_code: str
    :param city: The city of the airport.
    :type city: str
    :param country: The country of the airport.
    :type country: str
    :param ems_code: The airport code as it should be displayed by EMS apps.
    :type ems_code: str
    :param icao_code: The ICAO code is the international 4-letter identifier
     (e.g. KORD).
    :type icao_code: str
    :param latitude: The latitude of the airport.
    :type latitude: float
    :param longitude: The longitude of the airport.
    :type longitude: float
    :param altitude: The altitude of the airport
    :type altitude: float
    :param magnetic_variation: The magnetic variation of the airport.
    :type magnetic_variation: float
    :param type: The type of airport (e.g. civil, military)
    :type type: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'ata_code': {'key': 'ataCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'ems_code': {'key': 'emsCode', 'type': 'str'},
        'icao_code': {'key': 'icaoCode', 'type': 'str'},
        'latitude': {'key': 'latitude', 'type': 'float'},
        'longitude': {'key': 'longitude', 'type': 'float'},
        'altitude': {'key': 'altitude', 'type': 'float'},
        'magnetic_variation': {'key': 'magneticVariation', 'type': 'float'},
        'type': {'key': 'type', 'type': 'str'},
    }

    def __init__(self, *, id: int=None, name: str=None, ata_code: str=None, city: str=None, country: str=None, ems_code: str=None, icao_code: str=None, latitude: float=None, longitude: float=None, altitude: float=None, magnetic_variation: float=None, type: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoNavigationNavigationAirport, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.ata_code = ata_code
        self.city = city
        self.country = country
        self.ems_code = ems_code
        self.icao_code = icao_code
        self.latitude = latitude
        self.longitude = longitude
        self.altitude = altitude
        self.magnetic_variation = magnetic_variation
        self.type = type



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadUploadResult(Model):
    """Summarizes the result of an upload operation.

    :param transfer_successful: If this is true, the transfer was successful
     and also the transferred data are intact.
     This includes things like verifying the integrity of zip archives, for the
     overall transfer
     completion
    :type transfer_successful: bool
    :param message: If there was an error, then the error message will
     describe it. In the case of success, there
     may also be a message here. This message will be suitable for display to a
     user
    :type message: str
    """

    _attribute_map = {
        'transfer_successful': {'key': 'transferSuccessful', 'type': 'bool'},
        'message': {'key': 'message', 'type': 'str'},
    }

    def __init__(self, *, transfer_successful: bool=None, message: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoUploadUploadResult, self).__init__(**kwargs)
        self.transfer_successful = transfer_successful
        self.message = message



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange(Model):
    """Describes the current 10-minute average visual range for a runway, which is
    the distance over which a pilot
    can see the runway surface markings.

    All required parameters must be populated in order to send to Azure.

    :param runway: Required. The name/number/approach direction identifying
     the runway
    :type runway: str
    :param visibility_primary: The primary runway visibility distance in feet.
     If a variable range is set, this value describes the
     minimum visibility distance in a visual range
    :type visibility_primary: float
    :param visibility_primary_qualifier: A qualifier describing the primary
     visibility distance. Possible values include: 'equal', 'greaterThan',
     'lessThan'
    :type visibility_primary_qualifier: str or ~emsapi.models.enum
    :param visibility_variable: The variable runway visibility distance in
     feet, describing the maximum visibility distance in the
     visual range
    :type visibility_variable: float
    :param visibility_variable_qualifier: A qualifier describing the variable
     visibility distance. Possible values include: 'equal', 'greaterThan',
     'lessThan'
    :type visibility_variable_qualifier: str or ~emsapi.models.enum
    :param trend: The trend of the runway visibility distance. Possible values
     include: 'unknown', 'noChange', 'increasing', 'decreasing'
    :type trend: str or ~emsapi.models.enum
    """

    _validation = {
        'runway': {'required': True},
    }

    _attribute_map = {
        'runway': {'key': 'runway', 'type': 'str'},
        'visibility_primary': {'key': 'visibilityPrimary', 'type': 'float'},
        'visibility_primary_qualifier': {'key': 'visibilityPrimaryQualifier', 'type': 'str'},
        'visibility_variable': {'key': 'visibilityVariable', 'type': 'float'},
        'visibility_variable_qualifier': {'key': 'visibilityVariableQualifier', 'type': 'str'},
        'trend': {'key': 'trend', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange, self).__init__(**kwargs)
        self.runway = kwargs.get('runway', None)
        self.visibility_primary = kwargs.get('visibility_primary', None)
        self.visibility_primary_qualifier = kwargs.get('visibility_primary_qualifier', None)
        self.visibility_variable = kwargs.get('visibility_variable', None)
        self.visibility_variable_qualifier = kwargs.get('visibility_variable_qualifier', None)
        self.trend = kwargs.get('trend', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoWeatherWeatherReport(Model):
    """Represents TAF and METAR weather reports collected by an EMS system.

    All required parameters must be populated in order to send to Azure.

    :param taf_reports: Required. A list of collected TAF reports from an EMS
     system
    :type taf_reports:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherTafTafReport]
    :param metar_reports: Required. A list of collected METAR reports from an
     EMS system
    :type metar_reports:
     list[~emsapi.models.AdiEmsWebApiV2DtoWeatherMetarMetarReport]
    """

    _validation = {
        'taf_reports': {'required': True},
        'metar_reports': {'required': True},
    }

    _attribute_map = {
        'taf_reports': {'key': 'tafReports', 'type': '[AdiEmsWebApiV2DtoWeatherTafTafReport]'},
        'metar_reports': {'key': 'metarReports', 'type': '[AdiEmsWebApiV2DtoWeatherMetarMetarReport]'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoWeatherWeatherReport, self).__init__(**kwargs)
        self.taf_reports = kwargs.get('taf_reports', None)
        self.metar_reports = kwargs.get('metar_reports', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.pipeline import ClientRawResponse
from msrest.exceptions import HttpOperationError

from .. import models


class TrajectoryOperations(object):
    """TrajectoryOperations operations.

    :param client: Client for service requests.
    :param config: Configuration of service client.
    :param serializer: An object model serializer.
    :param deserializer: An object model deserializer.
    """

    models = models

    def __init__(self, client, config, serializer, deserializer):

        self._client = client
        self._serialize = serializer
        self._deserialize = deserializer

        self.config = config

    def get_kml_for_flight(
            self, ems_system_id, flight_id, trajectory_id, custom_headers=None, raw=False, **operation_config):
        """Returns trajectory content in "KML" format for a specific flight.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         retrieving the trajectory KML.
        :type flight_id: int
        :param trajectory_id: Identifier specifying the type of trajectory to
         provide.
        :type trajectory_id: str
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_kml_for_flight.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int'),
            'trajectoryId': self._serialize.url("trajectory_id", trajectory_id, 'str')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('object', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_kml_for_flight.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/kml-trajectories/{trajectoryId}'}

    def generate_trajectory_for_flight(
            self, ems_system_id, flight_id, start=None, end=None, custom_headers=None, raw=False, **operation_config):
        """Returns a trajectory path for a specific flight.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param flight_id: The integer ID of the flight record to use when
         retrieving the trajectory data.
        :type flight_id: int
        :param start: The start offset in the data, in seconds from the start
         of the data. If not specified, the beginning of the flight will be
         used.
        :type start: float
        :param end: The end offset in the data, in seconds from the start of
         the data. If not specified, the end of the flight will be used.
        :type end: float
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.generate_trajectory_for_flight.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int'),
            'flightId': self._serialize.url("flight_id", flight_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}
        if start is not None:
            query_parameters['start'] = self._serialize.query("start", start, 'float')
        if end is not None:
            query_parameters['end'] = self._serialize.query("end", end, 'float')

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('AdiEmsWebApiV2DtoTrajectoryValueArray', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    generate_trajectory_for_flight.metadata = {'url': '/v2/ems-systems/{emsSystemId}/flights/{flightId}/trajectories'}

    def get_trajectory_configurations(
            self, ems_system_id, custom_headers=None, raw=False, **operation_config):
        """Returns an array of KML trajectory options.

        :param ems_system_id: The unique identifier of the system containing
         the EMS data.
        :type ems_system_id: int
        :param dict custom_headers: headers that will be added to the request
        :param bool raw: returns the direct response alongside the
         deserialized response
        :param operation_config: :ref:`Operation configuration
         overrides<msrest:optionsforoperations>`.
        :return: object or ClientRawResponse if raw=true
        :rtype: object or ~msrest.pipeline.ClientRawResponse
        :raises:
         :class:`HttpOperationError<msrest.exceptions.HttpOperationError>`
        """
        # Construct URL
        url = self.get_trajectory_configurations.metadata['url']
        path_format_arguments = {
            'emsSystemId': self._serialize.url("ems_system_id", ems_system_id, 'int')
        }
        url = self._client.format_url(url, **path_format_arguments)

        # Construct parameters
        query_parameters = {}

        # Construct headers
        header_parameters = {}
        header_parameters['Accept'] = 'application/json'
        if custom_headers:
            header_parameters.update(custom_headers)

        # Construct and send request
        request = self._client.get(url, query_parameters, header_parameters)
        response = self._client.send(request, stream=False, **operation_config)

        if response.status_code not in [200, 401, 503]:
            raise HttpOperationError(self._deserialize, response)

        deserialized = None

        if response.status_code == 200:
            deserialized = self._deserialize('[AdiEmsWebApiV2DtoTrajectoryConfiguration]', response)
        if response.status_code == 401:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)
        if response.status_code == 503:
            deserialized = self._deserialize('AdiEmsWebApiModelError', response)

        if raw:
            client_raw_response = ClientRawResponse(deserialized, response)
            return client_raw_response

        return deserialized
    get_trajectory_configurations.metadata = {'url': '/v2/ems-systems/{emsSystemId}/trajectory-configurations'}



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoUploadBucket(Model):
    """The name and description of an upload bucket.

    :param name: The name of the bucket. This is unique
    :type name: str
    :param description: Description of the bucket
    :type description: str
    :param associated_ems_system: The EmsSystem that this bucket is associated
     with. This is used for determining
     the EMS Processing status when using the processing status API
    :type associated_ems_system: ~emsapi.models.AdiEmsWebDataModelEmsSystem
    """

    _attribute_map = {
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'associated_ems_system': {'key': 'associatedEmsSystem', 'type': 'AdiEmsWebDataModelEmsSystem'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoUploadBucket, self).__init__(**kwargs)
        self.name = kwargs.get('name', None)
        self.description = kwargs.get('description', None)
        self.associated_ems_system = kwargs.get('associated_ems_system', None)



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoAssetFleet(Model):
    """Represents a 'Fleet' in the EMS system.
    A fleet in this sense is a group of aircraft using the same configuration.
    There may be several fleets representing a particular model of aircraft,
    each showing a specific configuration
    of the airframe.

    :param id: The identifier of the fleet within the system.
    :type id: int
    :param description: The description for this fleet.
    :type description: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'description': {'key': 'description', 'type': 'str'},
    }

    def __init__(self, *, id: int=None, description: str=None, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoAssetFleet, self).__init__(**kwargs)
        self.id = id
        self.description = description



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoEmsProfileEmsProfile(Model):
    """Represents an APM (Automated Parameter Measurement) profile in an EMS
    system.

    All required parameters must be populated in order to send to Azure.

    :param profile_id: Required. The local identifier for a profile
    :type profile_id: int
    :param profile_guid: Required. The unique identifier of a profile in the
     system
    :type profile_guid: str
    :param profile_name: Required. The name of the profile
    :type profile_name: str
    :param library: Required. Flag for if a profile is a library profile
    :type library: bool
    :param current_version: Required. The version of the profile
    :type current_version: int
    :param path: Required. Path to the profile's location
    :type path: str
    """

    _validation = {
        'profile_id': {'required': True},
        'profile_guid': {'required': True},
        'profile_name': {'required': True},
        'library': {'required': True},
        'current_version': {'required': True},
        'path': {'required': True},
    }

    _attribute_map = {
        'profile_id': {'key': 'profileId', 'type': 'int'},
        'profile_guid': {'key': 'profileGuid', 'type': 'str'},
        'profile_name': {'key': 'profileName', 'type': 'str'},
        'library': {'key': 'library', 'type': 'bool'},
        'current_version': {'key': 'currentVersion', 'type': 'int'},
        'path': {'key': 'path', 'type': 'str'},
    }

    def __init__(self, *, profile_id: int, profile_guid: str, profile_name: str, library: bool, current_version: int, path: str, **kwargs) -> None:
        super(AdiEmsWebApiV2DtoEmsProfileEmsProfile, self).__init__(**kwargs)
        self.profile_id = profile_id
        self.profile_guid = profile_guid
        self.profile_name = profile_name
        self.library = library
        self.current_version = current_version
        self.path = path



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebDataModelEmsSystem(Model):
    """AdiEmsWebDataModelEmsSystem.

    :param id:
    :type id: int
    :param name:
    :type name: str
    :param description:
    :type description: str
    :param dir_adi:
    :type dir_adi: str
    :param dir_collection:
    :type dir_collection: str
    """

    _attribute_map = {
        'id': {'key': 'id', 'type': 'int'},
        'name': {'key': 'name', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'dir_adi': {'key': 'dirAdi', 'type': 'str'},
        'dir_collection': {'key': 'dirCollection', 'type': 'str'},
    }

    def __init__(self, *, id: int=None, name: str=None, description: str=None, dir_adi: str=None, dir_collection: str=None, **kwargs) -> None:
        super(AdiEmsWebDataModelEmsSystem, self).__init__(**kwargs)
        self.id = id
        self.name = name
        self.description = description
        self.dir_adi = dir_adi
        self.dir_collection = dir_collection



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

try:
    from .adi_ems_web_api_v2_model_analytic_analytic_id_py3 import AdiEmsWebApiV2ModelAnalyticAnalyticId
    from .adi_ems_web_api_v2_dto_analytic_info_py3 import AdiEmsWebApiV2DtoAnalyticInfo
    from .adi_ems_web_api_model_error_py3 import AdiEmsWebApiModelError
    from .adi_ems_web_api_v2_dto_analytic_group_py3 import AdiEmsWebApiV2DtoAnalyticGroup
    from .adi_ems_web_api_v2_dto_analytic_group_contents_py3 import AdiEmsWebApiV2DtoAnalyticGroupContents
    from .adi_ems_web_api_v2_model_analytic_analytic_select_py3 import AdiEmsWebApiV2ModelAnalyticAnalyticSelect
    from .adi_ems_web_api_v2_model_analytic_offset_type_py3 import AdiEmsWebApiV2ModelAnalyticOffsetType
    from .adi_ems_web_api_v2_model_analytic_query_py3 import AdiEmsWebApiV2ModelAnalyticQuery
    from .adi_ems_web_api_v2_model_analytic_analytic_result_py3 import AdiEmsWebApiV2ModelAnalyticAnalyticResult
    from .adi_ems_web_api_v2_model_analytic_query_result_py3 import AdiEmsWebApiV2ModelAnalyticQueryResult
    from .adi_ems_web_api_v2_dto_metadata_item_py3 import AdiEmsWebApiV2DtoMetadataItem
    from .adi_ems_web_api_v2_dto_metadata_py3 import AdiEmsWebApiV2DtoMetadata
    from .adi_ems_web_api_core_dto_data_range_py3 import AdiEmsWebApiCoreDtoDataRange
    from .adi_ems_web_api_v2_dto_analytic_set_analytic_set_item_py3 import AdiEmsWebApiV2DtoAnalyticSetAnalyticSetItem
    from .adi_ems_web_api_v2_dto_analytic_set_analytic_set_py3 import AdiEmsWebApiV2DtoAnalyticSetAnalyticSet
    from .adi_ems_web_api_v2_dto_analytic_set_analytic_set_group_py3 import AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup
    from .adi_ems_web_api_v2_dto_asset_fleet_py3 import AdiEmsWebApiV2DtoAssetFleet
    from .adi_ems_web_api_v2_dto_asset_aircraft_py3 import AdiEmsWebApiV2DtoAssetAircraft
    from .adi_ems_web_api_v2_dto_asset_flight_phase_py3 import AdiEmsWebApiV2DtoAssetFlightPhase
    from .adi_ems_web_api_v2_dto_asset_airport_py3 import AdiEmsWebApiV2DtoAssetAirport
    from .adi_ems_web_api_v2_dto_schema_database_py3 import AdiEmsWebApiV2DtoSchemaDatabase
    from .adi_ems_web_api_v2_dto_schema_database_group_py3 import AdiEmsWebApiV2DtoSchemaDatabaseGroup
    from .adi_ems_web_api_v2_dto_schema_field_py3 import AdiEmsWebApiV2DtoSchemaField
    from .adi_ems_web_api_v2_dto_schema_field_group_py3 import AdiEmsWebApiV2DtoSchemaFieldGroup
    from .adi_ems_web_api_v2_dto_schema_select_column_py3 import AdiEmsWebApiV2DtoSchemaSelectColumn
    from .adi_ems_web_api_v2_dto_schema_group_by_column_py3 import AdiEmsWebApiV2DtoSchemaGroupByColumn
    from .adi_ems_web_api_v2_dto_schema_order_by_column_py3 import AdiEmsWebApiV2DtoSchemaOrderByColumn
    from .adi_ems_web_api_v2_dto_schema_filter_argument_py3 import AdiEmsWebApiV2DtoSchemaFilterArgument
    from .adi_ems_web_api_v2_dto_schema_filter_py3 import AdiEmsWebApiV2DtoSchemaFilter
    from .adi_ems_web_api_v2_dto_schema_query_py3 import AdiEmsWebApiV2DtoSchemaQuery
    from .adi_ems_web_api_v2_dto_schema_query_result_header_py3 import AdiEmsWebApiV2DtoSchemaQueryResultHeader
    from .adi_ems_web_api_v2_dto_schema_query_result_py3 import AdiEmsWebApiV2DtoSchemaQueryResult
    from .adi_ems_web_api_v2_dto_schema_async_query_info_py3 import AdiEmsWebApiV2DtoSchemaAsyncQueryInfo
    from .adi_ems_web_api_v2_dto_schema_async_query_data_py3 import AdiEmsWebApiV2DtoSchemaAsyncQueryData
    from .adi_ems_web_api_v2_dto_ems_profile_profile_result_value_py3 import AdiEmsWebApiV2DtoEmsProfileProfileResultValue
    from .adi_ems_web_api_v2_dto_ems_profile_profile_result_comment_py3 import AdiEmsWebApiV2DtoEmsProfileProfileResultComment
    from .adi_ems_web_api_v2_dto_ems_profile_profile_results_event_record_py3 import AdiEmsWebApiV2DtoEmsProfileProfileResultsEventRecord
    from .adi_ems_web_api_v2_dto_ems_profile_profile_results_py3 import AdiEmsWebApiV2DtoEmsProfileProfileResults
    from .adi_ems_web_api_v2_dto_ems_profile_ems_profile_py3 import AdiEmsWebApiV2DtoEmsProfileEmsProfile
    from .adi_ems_web_api_v2_dto_ems_profile_glossary_item_py3 import AdiEmsWebApiV2DtoEmsProfileGlossaryItem
    from .adi_ems_web_api_v2_dto_ems_profile_ems_profile_glossary_py3 import AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary
    from .adi_ems_web_data_model_ems_system_py3 import AdiEmsWebDataModelEmsSystem
    from .adi_ems_web_api_v2_dto_navigation_navigation_airport_py3 import AdiEmsWebApiV2DtoNavigationNavigationAirport
    from .adi_ems_web_api_v2_dto_navigation_navigation_runway_py3 import AdiEmsWebApiV2DtoNavigationNavigationRunway
    from .adi_ems_web_api_v2_dto_navigation_navigation_procedure_py3 import AdiEmsWebApiV2DtoNavigationNavigationProcedure
    from .adi_ems_web_api_v2_dto_navigation_navigation_procedure_segment_navaid_py3 import AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid
    from .adi_ems_web_api_v2_dto_navigation_navigation_procedure_segment_py3 import AdiEmsWebApiV2DtoNavigationNavigationProcedureSegment
    from .adi_ems_web_api_v2_dto_navigation_navigation_waypoint_py3 import AdiEmsWebApiV2DtoNavigationNavigationWaypoint
    from .adi_ems_web_api_v2_dto_navigation_navigation_navaid_py3 import AdiEmsWebApiV2DtoNavigationNavigationNavaid
    from .adi_ems_web_api_v2_dto_parameter_set_parameter_set_item_py3 import AdiEmsWebApiV2DtoParameterSetParameterSetItem
    from .adi_ems_web_api_v2_dto_parameter_set_parameter_set_py3 import AdiEmsWebApiV2DtoParameterSetParameterSet
    from .adi_ems_web_api_v2_dto_parameter_set_parameter_set_group_py3 import AdiEmsWebApiV2DtoParameterSetParameterSetGroup
    from .adi_ems_web_api_v2_dto_profile_profile_result_value_py3 import AdiEmsWebApiV2DtoProfileProfileResultValue
    from .adi_ems_web_api_v2_dto_profile_profile_result_comment_py3 import AdiEmsWebApiV2DtoProfileProfileResultComment
    from .adi_ems_web_api_v2_dto_profile_profile_results_event_record_py3 import AdiEmsWebApiV2DtoProfileProfileResultsEventRecord
    from .adi_ems_web_api_v2_dto_profile_profile_results_py3 import AdiEmsWebApiV2DtoProfileProfileResults
    from .adi_ems_web_api_v2_dto_profile_profile_py3 import AdiEmsWebApiV2DtoProfileProfile
    from .adi_ems_web_api_v2_dto_profile_profile_group_py3 import AdiEmsWebApiV2DtoProfileProfileGroup
    from .adi_ems_web_api_v2_dto_profile_glossary_item_py3 import AdiEmsWebApiV2DtoProfileGlossaryItem
    from .adi_ems_web_api_v2_dto_profile_profile_glossary_py3 import AdiEmsWebApiV2DtoProfileProfileGlossary
    from .adi_ems_web_api_v2_dto_profile_event_py3 import AdiEmsWebApiV2DtoProfileEvent
    from .adi_ems_web_api_v2_model_tableau_trusted_py3 import AdiEmsWebApiV2ModelTableauTrusted
    from .adi_ems_web_api_v2_model_tableau_tableau_server_py3 import AdiEmsWebApiV2ModelTableauTableauServer
    from .adi_ems_web_shared_tableau_rest_site_py3 import AdiEmsWebSharedTableauRestSite
    from .adi_ems_web_shared_tableau_rest_project_py3 import AdiEmsWebSharedTableauRestProject
    from .adi_ems_web_shared_tableau_rest_user_py3 import AdiEmsWebSharedTableauRestUser
    from .adi_ems_web_shared_tableau_rest_tag_py3 import AdiEmsWebSharedTableauRestTag
    from .adi_ems_web_shared_tableau_rest_tags_py3 import AdiEmsWebSharedTableauRestTags
    from .adi_ems_web_shared_tableau_rest_view_py3 import AdiEmsWebSharedTableauRestView
    from .adi_ems_web_shared_tableau_rest_views_py3 import AdiEmsWebSharedTableauRestViews
    from .adi_ems_web_shared_tableau_rest_workbook_py3 import AdiEmsWebSharedTableauRestWorkbook
    from .adi_ems_web_api_v2_dto_trajectory_value_py3 import AdiEmsWebApiV2DtoTrajectoryValue
    from .adi_ems_web_api_v2_dto_trajectory_value_array_py3 import AdiEmsWebApiV2DtoTrajectoryValueArray
    from .adi_ems_web_api_v2_dto_trajectory_configuration_py3 import AdiEmsWebApiV2DtoTrajectoryConfiguration
    from .adi_ems_web_api_v2_dto_upload_upload_request_py3 import AdiEmsWebApiV2DtoUploadUploadRequest
    from .adi_ems_web_api_v2_dto_upload_upload_parameters_py3 import AdiEmsWebApiV2DtoUploadUploadParameters
    from .adi_ems_web_api_v2_dto_upload_upload_result_py3 import AdiEmsWebApiV2DtoUploadUploadResult
    from .adi_ems_web_api_v2_dto_upload_upload_status_py3 import AdiEmsWebApiV2DtoUploadUploadStatus
    from .adi_ems_web_api_v2_dto_upload_upload_record_py3 import AdiEmsWebApiV2DtoUploadUploadRecord
    from .adi_ems_web_api_v2_dto_upload_upload_processing_flight_status_py3 import AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus
    from .adi_ems_web_api_v2_dto_upload_upload_processing_status_py3 import AdiEmsWebApiV2DtoUploadUploadProcessingStatus
    from .adi_ems_web_api_v2_dto_upload_bucket_py3 import AdiEmsWebApiV2DtoUploadBucket
    from .adi_ems_web_api_v2_dto_weather_taf_taf_parse_options_py3 import AdiEmsWebApiV2DtoWeatherTafTafParseOptions
    from .adi_ems_web_api_v2_dto_weather_cloud_condition_py3 import AdiEmsWebApiV2DtoWeatherCloudCondition
    from .adi_ems_web_api_v2_dto_weather_taf_icing_condition_py3 import AdiEmsWebApiV2DtoWeatherTafIcingCondition
    from .adi_ems_web_api_v2_dto_weather_taf_turbulence_condition_py3 import AdiEmsWebApiV2DtoWeatherTafTurbulenceCondition
    from .adi_ems_web_api_v2_dto_weather_taf_temperature_py3 import AdiEmsWebApiV2DtoWeatherTafTemperature
    from .adi_ems_web_api_v2_dto_weather_taf_prediction_py3 import AdiEmsWebApiV2DtoWeatherTafPrediction
    from .adi_ems_web_api_v2_dto_weather_taf_taf_report_py3 import AdiEmsWebApiV2DtoWeatherTafTafReport
    from .adi_ems_web_api_v2_dto_weather_metar_metar_parse_options_py3 import AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions
    from .adi_ems_web_api_v2_dto_weather_metar_runway_visual_range_py3 import AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange
    from .adi_ems_web_api_v2_dto_weather_weather_phenomenon_py3 import AdiEmsWebApiV2DtoWeatherWeatherPhenomenon
    from .adi_ems_web_api_v2_dto_weather_metar_runway_condition_py3 import AdiEmsWebApiV2DtoWeatherMetarRunwayCondition
    from .adi_ems_web_api_v2_dto_weather_metar_metar_report_py3 import AdiEmsWebApiV2DtoWeatherMetarMetarReport
    from .adi_ems_web_api_v2_dto_weather_taf_taf_query_py3 import AdiEmsWebApiV2DtoWeatherTafTafQuery
    from .adi_ems_web_api_v2_dto_weather_metar_metar_query_py3 import AdiEmsWebApiV2DtoWeatherMetarMetarQuery
    from .adi_ems_web_api_v2_dto_weather_weather_report_py3 import AdiEmsWebApiV2DtoWeatherWeatherReport
except (SyntaxError, ImportError):
    from .adi_ems_web_api_v2_model_analytic_analytic_id import AdiEmsWebApiV2ModelAnalyticAnalyticId
    from .adi_ems_web_api_v2_dto_analytic_info import AdiEmsWebApiV2DtoAnalyticInfo
    from .adi_ems_web_api_model_error import AdiEmsWebApiModelError
    from .adi_ems_web_api_v2_dto_analytic_group import AdiEmsWebApiV2DtoAnalyticGroup
    from .adi_ems_web_api_v2_dto_analytic_group_contents import AdiEmsWebApiV2DtoAnalyticGroupContents
    from .adi_ems_web_api_v2_model_analytic_analytic_select import AdiEmsWebApiV2ModelAnalyticAnalyticSelect
    from .adi_ems_web_api_v2_model_analytic_offset_type import AdiEmsWebApiV2ModelAnalyticOffsetType
    from .adi_ems_web_api_v2_model_analytic_query import AdiEmsWebApiV2ModelAnalyticQuery
    from .adi_ems_web_api_v2_model_analytic_analytic_result import AdiEmsWebApiV2ModelAnalyticAnalyticResult
    from .adi_ems_web_api_v2_model_analytic_query_result import AdiEmsWebApiV2ModelAnalyticQueryResult
    from .adi_ems_web_api_v2_dto_metadata_item import AdiEmsWebApiV2DtoMetadataItem
    from .adi_ems_web_api_v2_dto_metadata import AdiEmsWebApiV2DtoMetadata
    from .adi_ems_web_api_core_dto_data_range import AdiEmsWebApiCoreDtoDataRange
    from .adi_ems_web_api_v2_dto_analytic_set_analytic_set_item import AdiEmsWebApiV2DtoAnalyticSetAnalyticSetItem
    from .adi_ems_web_api_v2_dto_analytic_set_analytic_set import AdiEmsWebApiV2DtoAnalyticSetAnalyticSet
    from .adi_ems_web_api_v2_dto_analytic_set_analytic_set_group import AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup
    from .adi_ems_web_api_v2_dto_asset_fleet import AdiEmsWebApiV2DtoAssetFleet
    from .adi_ems_web_api_v2_dto_asset_aircraft import AdiEmsWebApiV2DtoAssetAircraft
    from .adi_ems_web_api_v2_dto_asset_flight_phase import AdiEmsWebApiV2DtoAssetFlightPhase
    from .adi_ems_web_api_v2_dto_asset_airport import AdiEmsWebApiV2DtoAssetAirport
    from .adi_ems_web_api_v2_dto_schema_database import AdiEmsWebApiV2DtoSchemaDatabase
    from .adi_ems_web_api_v2_dto_schema_database_group import AdiEmsWebApiV2DtoSchemaDatabaseGroup
    from .adi_ems_web_api_v2_dto_schema_field import AdiEmsWebApiV2DtoSchemaField
    from .adi_ems_web_api_v2_dto_schema_field_group import AdiEmsWebApiV2DtoSchemaFieldGroup
    from .adi_ems_web_api_v2_dto_schema_select_column import AdiEmsWebApiV2DtoSchemaSelectColumn
    from .adi_ems_web_api_v2_dto_schema_group_by_column import AdiEmsWebApiV2DtoSchemaGroupByColumn
    from .adi_ems_web_api_v2_dto_schema_order_by_column import AdiEmsWebApiV2DtoSchemaOrderByColumn
    from .adi_ems_web_api_v2_dto_schema_filter_argument import AdiEmsWebApiV2DtoSchemaFilterArgument
    from .adi_ems_web_api_v2_dto_schema_filter import AdiEmsWebApiV2DtoSchemaFilter
    from .adi_ems_web_api_v2_dto_schema_query import AdiEmsWebApiV2DtoSchemaQuery
    from .adi_ems_web_api_v2_dto_schema_query_result_header import AdiEmsWebApiV2DtoSchemaQueryResultHeader
    from .adi_ems_web_api_v2_dto_schema_query_result import AdiEmsWebApiV2DtoSchemaQueryResult
    from .adi_ems_web_api_v2_dto_schema_async_query_info import AdiEmsWebApiV2DtoSchemaAsyncQueryInfo
    from .adi_ems_web_api_v2_dto_schema_async_query_data import AdiEmsWebApiV2DtoSchemaAsyncQueryData
    from .adi_ems_web_api_v2_dto_ems_profile_profile_result_value import AdiEmsWebApiV2DtoEmsProfileProfileResultValue
    from .adi_ems_web_api_v2_dto_ems_profile_profile_result_comment import AdiEmsWebApiV2DtoEmsProfileProfileResultComment
    from .adi_ems_web_api_v2_dto_ems_profile_profile_results_event_record import AdiEmsWebApiV2DtoEmsProfileProfileResultsEventRecord
    from .adi_ems_web_api_v2_dto_ems_profile_profile_results import AdiEmsWebApiV2DtoEmsProfileProfileResults
    from .adi_ems_web_api_v2_dto_ems_profile_ems_profile import AdiEmsWebApiV2DtoEmsProfileEmsProfile
    from .adi_ems_web_api_v2_dto_ems_profile_glossary_item import AdiEmsWebApiV2DtoEmsProfileGlossaryItem
    from .adi_ems_web_api_v2_dto_ems_profile_ems_profile_glossary import AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary
    from .adi_ems_web_data_model_ems_system import AdiEmsWebDataModelEmsSystem
    from .adi_ems_web_api_v2_dto_navigation_navigation_airport import AdiEmsWebApiV2DtoNavigationNavigationAirport
    from .adi_ems_web_api_v2_dto_navigation_navigation_runway import AdiEmsWebApiV2DtoNavigationNavigationRunway
    from .adi_ems_web_api_v2_dto_navigation_navigation_procedure import AdiEmsWebApiV2DtoNavigationNavigationProcedure
    from .adi_ems_web_api_v2_dto_navigation_navigation_procedure_segment_navaid import AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid
    from .adi_ems_web_api_v2_dto_navigation_navigation_procedure_segment import AdiEmsWebApiV2DtoNavigationNavigationProcedureSegment
    from .adi_ems_web_api_v2_dto_navigation_navigation_waypoint import AdiEmsWebApiV2DtoNavigationNavigationWaypoint
    from .adi_ems_web_api_v2_dto_navigation_navigation_navaid import AdiEmsWebApiV2DtoNavigationNavigationNavaid
    from .adi_ems_web_api_v2_dto_parameter_set_parameter_set_item import AdiEmsWebApiV2DtoParameterSetParameterSetItem
    from .adi_ems_web_api_v2_dto_parameter_set_parameter_set import AdiEmsWebApiV2DtoParameterSetParameterSet
    from .adi_ems_web_api_v2_dto_parameter_set_parameter_set_group import AdiEmsWebApiV2DtoParameterSetParameterSetGroup
    from .adi_ems_web_api_v2_dto_profile_profile_result_value import AdiEmsWebApiV2DtoProfileProfileResultValue
    from .adi_ems_web_api_v2_dto_profile_profile_result_comment import AdiEmsWebApiV2DtoProfileProfileResultComment
    from .adi_ems_web_api_v2_dto_profile_profile_results_event_record import AdiEmsWebApiV2DtoProfileProfileResultsEventRecord
    from .adi_ems_web_api_v2_dto_profile_profile_results import AdiEmsWebApiV2DtoProfileProfileResults
    from .adi_ems_web_api_v2_dto_profile_profile import AdiEmsWebApiV2DtoProfileProfile
    from .adi_ems_web_api_v2_dto_profile_profile_group import AdiEmsWebApiV2DtoProfileProfileGroup
    from .adi_ems_web_api_v2_dto_profile_glossary_item import AdiEmsWebApiV2DtoProfileGlossaryItem
    from .adi_ems_web_api_v2_dto_profile_profile_glossary import AdiEmsWebApiV2DtoProfileProfileGlossary
    from .adi_ems_web_api_v2_dto_profile_event import AdiEmsWebApiV2DtoProfileEvent
    from .adi_ems_web_api_v2_model_tableau_trusted import AdiEmsWebApiV2ModelTableauTrusted
    from .adi_ems_web_api_v2_model_tableau_tableau_server import AdiEmsWebApiV2ModelTableauTableauServer
    from .adi_ems_web_shared_tableau_rest_site import AdiEmsWebSharedTableauRestSite
    from .adi_ems_web_shared_tableau_rest_project import AdiEmsWebSharedTableauRestProject
    from .adi_ems_web_shared_tableau_rest_user import AdiEmsWebSharedTableauRestUser
    from .adi_ems_web_shared_tableau_rest_tag import AdiEmsWebSharedTableauRestTag
    from .adi_ems_web_shared_tableau_rest_tags import AdiEmsWebSharedTableauRestTags
    from .adi_ems_web_shared_tableau_rest_view import AdiEmsWebSharedTableauRestView
    from .adi_ems_web_shared_tableau_rest_views import AdiEmsWebSharedTableauRestViews
    from .adi_ems_web_shared_tableau_rest_workbook import AdiEmsWebSharedTableauRestWorkbook
    from .adi_ems_web_api_v2_dto_trajectory_value import AdiEmsWebApiV2DtoTrajectoryValue
    from .adi_ems_web_api_v2_dto_trajectory_value_array import AdiEmsWebApiV2DtoTrajectoryValueArray
    from .adi_ems_web_api_v2_dto_trajectory_configuration import AdiEmsWebApiV2DtoTrajectoryConfiguration
    from .adi_ems_web_api_v2_dto_upload_upload_request import AdiEmsWebApiV2DtoUploadUploadRequest
    from .adi_ems_web_api_v2_dto_upload_upload_parameters import AdiEmsWebApiV2DtoUploadUploadParameters
    from .adi_ems_web_api_v2_dto_upload_upload_result import AdiEmsWebApiV2DtoUploadUploadResult
    from .adi_ems_web_api_v2_dto_upload_upload_status import AdiEmsWebApiV2DtoUploadUploadStatus
    from .adi_ems_web_api_v2_dto_upload_upload_record import AdiEmsWebApiV2DtoUploadUploadRecord
    from .adi_ems_web_api_v2_dto_upload_upload_processing_flight_status import AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus
    from .adi_ems_web_api_v2_dto_upload_upload_processing_status import AdiEmsWebApiV2DtoUploadUploadProcessingStatus
    from .adi_ems_web_api_v2_dto_upload_bucket import AdiEmsWebApiV2DtoUploadBucket
    from .adi_ems_web_api_v2_dto_weather_taf_taf_parse_options import AdiEmsWebApiV2DtoWeatherTafTafParseOptions
    from .adi_ems_web_api_v2_dto_weather_cloud_condition import AdiEmsWebApiV2DtoWeatherCloudCondition
    from .adi_ems_web_api_v2_dto_weather_taf_icing_condition import AdiEmsWebApiV2DtoWeatherTafIcingCondition
    from .adi_ems_web_api_v2_dto_weather_taf_turbulence_condition import AdiEmsWebApiV2DtoWeatherTafTurbulenceCondition
    from .adi_ems_web_api_v2_dto_weather_taf_temperature import AdiEmsWebApiV2DtoWeatherTafTemperature
    from .adi_ems_web_api_v2_dto_weather_taf_prediction import AdiEmsWebApiV2DtoWeatherTafPrediction
    from .adi_ems_web_api_v2_dto_weather_taf_taf_report import AdiEmsWebApiV2DtoWeatherTafTafReport
    from .adi_ems_web_api_v2_dto_weather_metar_metar_parse_options import AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions
    from .adi_ems_web_api_v2_dto_weather_metar_runway_visual_range import AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange
    from .adi_ems_web_api_v2_dto_weather_weather_phenomenon import AdiEmsWebApiV2DtoWeatherWeatherPhenomenon
    from .adi_ems_web_api_v2_dto_weather_metar_runway_condition import AdiEmsWebApiV2DtoWeatherMetarRunwayCondition
    from .adi_ems_web_api_v2_dto_weather_metar_metar_report import AdiEmsWebApiV2DtoWeatherMetarMetarReport
    from .adi_ems_web_api_v2_dto_weather_taf_taf_query import AdiEmsWebApiV2DtoWeatherTafTafQuery
    from .adi_ems_web_api_v2_dto_weather_metar_metar_query import AdiEmsWebApiV2DtoWeatherMetarMetarQuery
    from .adi_ems_web_api_v2_dto_weather_weather_report import AdiEmsWebApiV2DtoWeatherWeatherReport

__all__ = [
    'AdiEmsWebApiV2ModelAnalyticAnalyticId',
    'AdiEmsWebApiV2DtoAnalyticInfo',
    'AdiEmsWebApiModelError',
    'AdiEmsWebApiV2DtoAnalyticGroup',
    'AdiEmsWebApiV2DtoAnalyticGroupContents',
    'AdiEmsWebApiV2ModelAnalyticAnalyticSelect',
    'AdiEmsWebApiV2ModelAnalyticOffsetType',
    'AdiEmsWebApiV2ModelAnalyticQuery',
    'AdiEmsWebApiV2ModelAnalyticAnalyticResult',
    'AdiEmsWebApiV2ModelAnalyticQueryResult',
    'AdiEmsWebApiV2DtoMetadataItem',
    'AdiEmsWebApiV2DtoMetadata',
    'AdiEmsWebApiCoreDtoDataRange',
    'AdiEmsWebApiV2DtoAnalyticSetAnalyticSetItem',
    'AdiEmsWebApiV2DtoAnalyticSetAnalyticSet',
    'AdiEmsWebApiV2DtoAnalyticSetAnalyticSetGroup',
    'AdiEmsWebApiV2DtoAssetFleet',
    'AdiEmsWebApiV2DtoAssetAircraft',
    'AdiEmsWebApiV2DtoAssetFlightPhase',
    'AdiEmsWebApiV2DtoAssetAirport',
    'AdiEmsWebApiV2DtoSchemaDatabase',
    'AdiEmsWebApiV2DtoSchemaDatabaseGroup',
    'AdiEmsWebApiV2DtoSchemaField',
    'AdiEmsWebApiV2DtoSchemaFieldGroup',
    'AdiEmsWebApiV2DtoSchemaSelectColumn',
    'AdiEmsWebApiV2DtoSchemaGroupByColumn',
    'AdiEmsWebApiV2DtoSchemaOrderByColumn',
    'AdiEmsWebApiV2DtoSchemaFilterArgument',
    'AdiEmsWebApiV2DtoSchemaFilter',
    'AdiEmsWebApiV2DtoSchemaQuery',
    'AdiEmsWebApiV2DtoSchemaQueryResultHeader',
    'AdiEmsWebApiV2DtoSchemaQueryResult',
    'AdiEmsWebApiV2DtoSchemaAsyncQueryInfo',
    'AdiEmsWebApiV2DtoSchemaAsyncQueryData',
    'AdiEmsWebApiV2DtoEmsProfileProfileResultValue',
    'AdiEmsWebApiV2DtoEmsProfileProfileResultComment',
    'AdiEmsWebApiV2DtoEmsProfileProfileResultsEventRecord',
    'AdiEmsWebApiV2DtoEmsProfileProfileResults',
    'AdiEmsWebApiV2DtoEmsProfileEmsProfile',
    'AdiEmsWebApiV2DtoEmsProfileGlossaryItem',
    'AdiEmsWebApiV2DtoEmsProfileEmsProfileGlossary',
    'AdiEmsWebDataModelEmsSystem',
    'AdiEmsWebApiV2DtoNavigationNavigationAirport',
    'AdiEmsWebApiV2DtoNavigationNavigationRunway',
    'AdiEmsWebApiV2DtoNavigationNavigationProcedure',
    'AdiEmsWebApiV2DtoNavigationNavigationProcedureSegmentNavaid',
    'AdiEmsWebApiV2DtoNavigationNavigationProcedureSegment',
    'AdiEmsWebApiV2DtoNavigationNavigationWaypoint',
    'AdiEmsWebApiV2DtoNavigationNavigationNavaid',
    'AdiEmsWebApiV2DtoParameterSetParameterSetItem',
    'AdiEmsWebApiV2DtoParameterSetParameterSet',
    'AdiEmsWebApiV2DtoParameterSetParameterSetGroup',
    'AdiEmsWebApiV2DtoProfileProfileResultValue',
    'AdiEmsWebApiV2DtoProfileProfileResultComment',
    'AdiEmsWebApiV2DtoProfileProfileResultsEventRecord',
    'AdiEmsWebApiV2DtoProfileProfileResults',
    'AdiEmsWebApiV2DtoProfileProfile',
    'AdiEmsWebApiV2DtoProfileProfileGroup',
    'AdiEmsWebApiV2DtoProfileGlossaryItem',
    'AdiEmsWebApiV2DtoProfileProfileGlossary',
    'AdiEmsWebApiV2DtoProfileEvent',
    'AdiEmsWebApiV2ModelTableauTrusted',
    'AdiEmsWebApiV2ModelTableauTableauServer',
    'AdiEmsWebSharedTableauRestSite',
    'AdiEmsWebSharedTableauRestProject',
    'AdiEmsWebSharedTableauRestUser',
    'AdiEmsWebSharedTableauRestTag',
    'AdiEmsWebSharedTableauRestTags',
    'AdiEmsWebSharedTableauRestView',
    'AdiEmsWebSharedTableauRestViews',
    'AdiEmsWebSharedTableauRestWorkbook',
    'AdiEmsWebApiV2DtoTrajectoryValue',
    'AdiEmsWebApiV2DtoTrajectoryValueArray',
    'AdiEmsWebApiV2DtoTrajectoryConfiguration',
    'AdiEmsWebApiV2DtoUploadUploadRequest',
    'AdiEmsWebApiV2DtoUploadUploadParameters',
    'AdiEmsWebApiV2DtoUploadUploadResult',
    'AdiEmsWebApiV2DtoUploadUploadStatus',
    'AdiEmsWebApiV2DtoUploadUploadRecord',
    'AdiEmsWebApiV2DtoUploadUploadProcessingFlightStatus',
    'AdiEmsWebApiV2DtoUploadUploadProcessingStatus',
    'AdiEmsWebApiV2DtoUploadBucket',
    'AdiEmsWebApiV2DtoWeatherTafTafParseOptions',
    'AdiEmsWebApiV2DtoWeatherCloudCondition',
    'AdiEmsWebApiV2DtoWeatherTafIcingCondition',
    'AdiEmsWebApiV2DtoWeatherTafTurbulenceCondition',
    'AdiEmsWebApiV2DtoWeatherTafTemperature',
    'AdiEmsWebApiV2DtoWeatherTafPrediction',
    'AdiEmsWebApiV2DtoWeatherTafTafReport',
    'AdiEmsWebApiV2DtoWeatherMetarMetarParseOptions',
    'AdiEmsWebApiV2DtoWeatherMetarRunwayVisualRange',
    'AdiEmsWebApiV2DtoWeatherWeatherPhenomenon',
    'AdiEmsWebApiV2DtoWeatherMetarRunwayCondition',
    'AdiEmsWebApiV2DtoWeatherMetarMetarReport',
    'AdiEmsWebApiV2DtoWeatherTafTafQuery',
    'AdiEmsWebApiV2DtoWeatherMetarMetarQuery',
    'AdiEmsWebApiV2DtoWeatherWeatherReport',
]



# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class AdiEmsWebApiV2DtoSchemaOrderByColumn(Model):
    """Represents a column of data that can be used in a order-by clause of a data
    source query.

    All required parameters must be populated in order to send to Azure.

    :param field_id: Required. The unique string identifier of the field to
     use in a order-by clause of a query
    :type field_id: str
    :param aggregate: An optional aggregate operation to perform on the
     column. Omission of this property results in no aggregate
     operation being used in the ordering. Possible values include: 'none',
     'avg', 'count', 'max', 'min', 'stdev', 'sum', 'var'
    :type aggregate: str or ~emsapi.models.enum
    :param order: The ordering behavior to use for the column values. The
     omission of this property results in ascending order. Possible values
     include: 'asc', 'desc'
    :type order: str or ~emsapi.models.enum
    """

    _validation = {
        'field_id': {'required': True},
    }

    _attribute_map = {
        'field_id': {'key': 'fieldId', 'type': 'str'},
        'aggregate': {'key': 'aggregate', 'type': 'str'},
        'order': {'key': 'order', 'type': 'str'},
    }

    def __init__(self, **kwargs):
        super(AdiEmsWebApiV2DtoSchemaOrderByColumn, self).__init__(**kwargs)
        self.field_id = kwargs.get('field_id', None)
        self.aggregate = kwargs.get('aggregate', None)
        self.order = kwargs.get('order', None)



import json
import requests
import logging

from emsapi import emsapi
from datetime import datetime
from datetime import timedelta
from msrest import authentication

class EmsApiAuthError(Exception):
    """
    Generic exception for auth errors
    """
    def __init__(self, msg, original_exception=None):
        message = msg
        if original_exception:
            message = message + f": {original_exception}"
        super(EmsApiAuthError, self).__init__(message)
        self.original_exception = original_exception

class EmsApiTokenAuthentication(authentication.Authentication):
    def __init__(self, user: str, password: str, url: str):
        self.scheme = 'Bearer'
        self.user = user
        self.password = password
        self.url = url
        self.token = None
        self.expiration = None
        self.logger = logging.getLogger(__name__)
        if not self.url.endswith('/'):
            self.url = self.url + '/'

    def set_token(self):
        """
        Retrieves a new token for the EMS API.
        """
        authorization_url = self.url + "token"
        body = "grant_type=password&username=" + self.user +"&password=" + self.password
        try:
            response = requests.post(authorization_url, body)
        except requests.RequestException as e:
            raise EmsApiAuthError("An EMS API authentication error occurred.", e)
        
        if response.ok:
            self.logger.info(f"Retrieved new auth token for {self.url}")
            self.token = json.loads(response.text)
            
            # Subtract 5 seconds from the expiration time to account for long running requests.
            delta_seconds = self.token['expires_in'] - 5
            self.expiration = datetime.now() + timedelta(seconds=delta_seconds)
        else:
            raise EmsApiAuthError(f"The authentication token request failed with the HTTP code {response.status_code}")
            
    def is_expired(self):
        """
        Returns true if the token has expired and needs to be refreshed.
        """
        if self.token is None or self.expiration is None:
            return True
        return datetime.now() > self.expiration
            
    def signed_session(self, session=None):
        """
        Creates a new session, or configures an existing one.
        """
        session = super(EmsApiTokenAuthentication, self).signed_session(session)
        if not self.token or self.is_expired():
            self.set_token()
            
        header = "{} {}".format(self.scheme, self.token['access_token'])
        session.headers['Authorization'] = header
        return session
    
class EmsSystemHelper:
    systems = {}
    
    @staticmethod
    def find_id(client: emsapi, name: str):
        # Cache by base url
        url = client.config.base_url
        cached = EmsSystemHelper.systems.get(url)
        if not cached:
            EmsSystemHelper.systems[url] = client.ems_system.get_ems_systems()
        
        # We don't require an exact match (use find).
        matching = [s 
                    for s in EmsSystemHelper.systems[url]
                    if s.name.lower().find(name.lower()) > -1]

        # But we do require there to be exactly one match, to avoid ambiguity.
        if len(matching) == 0:
            raise ValueError(f"An EMS system was not found with the name {name}")
        elif len(matching) == 1:
            return matching[0].id
        else:
            raise ValueError(f"More than one EMS system was found with the name {name}")